@@ -5,14 +5,17 @@ from google.cloud import storage
 
 def bucket(payload: dict = None, ips: dict = None) -> storage.Bucket:
   if payload is not None:
-    return _bucket_for_ips(payload['ips'])
+    return bucket_for_ips(payload['ips'])
   elif ips is not None:
-    return _bucket_for_ips(ips)
+    return bucket_for_ips(ips)
   return None
 
-def _bucket_for_ips(ips: dict) -> storage.Bucket:
+def bucket_for_ips(ips: dict) -> storage.Bucket:
+  return bucket_by_name(ips['bucketId'])
+
+def bucket_by_name(named: str) -> storage.Bucket:
   gcs = storage.Client()
-  return gcs.get_bucket(ips['bucketId'])
+  return gcs.get_bucket(named)
 
 def download_extract(bucket: storage.Bucket, remote_path: str, local_file: str):
   print(f"downloading file <{remote_path}> to local file {local_file}")
