@@ -16,6 +16,23 @@ def extract_postcode_from_address(addr: str, raiseFailures: bool = True) -> tupl
 def extract_postcode_from_address_series(s: pandas.Series) -> tuple[str, str]:
   return pandas.Series(extract_postcode_from_address(s['address_1'], False))
 
+def extract_full_name(full_name: str) -> tuple[str, str]:
+  parts = full_name.strip().split()
+  first_name = parts[0]
+  last_name = ' '.join(parts[1:]).strip()
+  if last_name == '': last_name = None
+  return first_name, last_name
+
+def extract_full_name_from_series(s: pandas.Series, key: str) -> tuple[str, str]:
+  return pandas.Series(extract_full_name(s[key]))
+
+def extract_full_name_from_df(df: pandas.DataFrame) -> pandas.DataFrame:
+  for scenario in ['full_name', 'forename_surname']:
+    if scenario in df.columns:
+      df[['forename', 'surname']] = df.apply(lambda s: extract_full_name_from_series(s, scenario), axis=1)
+      df.drop(columns=[scenario], inplace=True)
+  return df
+
 def break_out_individuals_cpl(
     df: pandas.DataFrame,
     header_map: dict, 
@@ -38,6 +55,9 @@ def break_out_individuals_cpl(
   # rename pii columns
   renamed_df = df.rename(columns=header_map)
 
+  # full name could be a single column
+  renamed_df = extract_full_name_from_df(renamed_df)
+
   # all possible columns we may need to include
   extras = additional_columns if additional_columns is not None else []
   claimant_columns = extras + ['unique_id', 'nino', 'surname', 'forename', 'date_of_birth', 'address_1', 'address_2', 'address_3', 'postcode']
